@@ -86,8 +86,23 @@ class YtmusicProvider(AbstractProvider, ProviderV2):
     def try_get_user_with_headerfile(self):
         if HEADER_FILE.exists():
             self.service.reinitialize_by_headerfile(HEADER_FILE)
-            user = self.user_get("")
-            return user
+            try:
+                info = self.service.get_current_account_info()
+            except Exception as e:
+                logger.info("Auto login failed to get account info: %s", e)
+                return None
+            gaia_id = info.get("gaiaId")
+            if gaia_id:
+                try:
+                    info = self.service.switch_profile(gaia_id=gaia_id)
+                except Exception as e:
+                    logger.warning("Auto login profile switch failed: %s", e)
+            return UserModel(
+                identifier=info.get("channelId") or "",
+                source=self.meta.identifier,
+                name=info["accountName"],
+                avatar_url=info["accountPhotoUrl"],
+            )
         return None
 
     def has_current_user(self) -> bool:
@@ -102,11 +117,11 @@ class YtmusicProvider(AbstractProvider, ProviderV2):
         # HACK: empty string means the current user.
         if identifier == "":
             try:
-                info = self.service.api.get_account_info()
+                info = self.service.get_current_account_info()
             except Exception as e:
                 raise ProviderIOError(f"get current account info failed: {e}")
             return UserModel(
-                identifier="",
+                identifier=info.get("channelId") or "",
                 source=self.meta.identifier,
                 name=info["accountName"],
                 avatar_url=info["accountPhotoUrl"],
@@ -119,6 +134,26 @@ class YtmusicProvider(AbstractProvider, ProviderV2):
             name=user.name,
         )
 
+    def list_profiles(self):
+        return self.service.list_profiles()
+
+    def switch_profile(self, account_name: str = None, gaia_id: str = None):
+        try:
+            info = self.service.switch_profile(
+                account_name=account_name, gaia_id=gaia_id
+            )
+        except Exception as e:
+            raise ProviderIOError(f"switch profile failed: {e}")
+        user = UserModel(
+            identifier=info.get("channelId") or "",
+            source=self.meta.identifier,
+            name=info["accountName"],
+            avatar_url=info["accountPhotoUrl"],
+        )
+        self.auth(user)
+        self.current_user_changed.emit(user)
+        return user
+
     def current_user_list_playlists(self):
         playlists = self.service.library_playlists(100)
         # HACK: FeelUOwn fetches playlists in two places:
